Bug #40634 table scan temporary table is 4x slower due to mmap instead instead of caching
| Submitted: | 11 Nov 2008 11:30 | Modified: | 23 Mar 2009 2:06 |
|---|---|---|---|
| Reporter: | Shane Bester (Platinum Quality Contributor) | Email Updates: | |
| Status: | Closed | Impact on me: | |
| Category: | MySQL Server: MyISAM storage engine | Severity: | S5 (Performance) |
| Version: | 5.1.29, 6.0.x | OS: | Any |
| Assigned to: | Alexey Botchkov | CPU Architecture: | Any |
| Tags: | mmap, read_buffer_size, regression, table scan, temporary table | ||
- View
- Add Comment
- Files
- Developer
- Edit Submission
- View Progress Log
- Contributions
Contributions can be accepted to Open bugs only.
Portions of this website are copyright © 2001, 2002 The PHP Group
Page generated in 0.037 sec. using MySQL 8.4.7-u6-cloud
Timestamp references displayed by the system are UTC.
Content reproduced on this site is the property of the
respective copyright holders.
It is not reviewed in advance
by Oracle and does not necessarily represent the opinion of
Oracle or any other party.